@@ -130,7 +130,7 @@ class NavParser:
     def break_NMEA_into_blocks(self, nmea_lines):
         blocks = []
         for line in nmea_lines:
-            self._nmea_block_buffer += line
+            self._nmea_block_buffer += f'{line}\n'
             self._nmea_buffer_flags = {k: True if k in line else v for k, v in self._nmea_buffer_flags.items()}
             for flag in self._nmea_buffer_flags:
                 self._nmea_buffer_flags[flag] = True if flag in line else self._nmea_buffer_flags[flag]
